@@ -23,26 +23,19 @@ class Configuration:
     author: str
     email: str
     licence: str
-    _template: typing.Optional["Configuration"] = dataclasses.field(init=False)
+    template: typing.Optional["Configuration"] = dataclasses.field(init=False)
 
     def __init__(  # pylint: disable=R0913
         self,
         project_path: pathlib.Path,
-        project_name: typing.Union[_project_name.ProjectName, str],
+        project_name: _project_name.ProjectName,
         author: str,
         email: str,
         licence: str,
     ):
         """Construct a Configuration."""
         self.project_path = project_path
-        if isinstance(project_name, str):
-            self.project_name = _project_name.ProjectName(project_name)
-        elif isinstance(project_name, _project_name.ProjectName):
-            self.project_name = project_name
-        else:
-            raise ValueError(
-                f"project_name must be a ProjectName or str, not {type(project_name)}"
-            )
+        self.project_name = project_name
         self.author = author
         self.email = email
         self.licence = licence
@@ -66,7 +59,7 @@ class Configuration:
 
         author, email = pyproject["tool"]["poetry"]["authors"][0].split(" <")
 
-        self._template = Configuration(
+        self.template = Configuration(
             project_path=self.project_path,
             project_name=project_name,
             author=author,
@@ -76,18 +69,18 @@ class Configuration:
 
     def sub(self, text: str) -> str:
         """Substitute template parameters in given string."""
-        if self._template is None:
+        if self.template is None:
             raise NotImplementedError(
                 "sub is only available on Configurations with an internal template."
             )
         result = text
         result = result.replace(
-            self._template.project_name.original, self.project_name.original
+            self.template.project_name.original, self.project_name.original
         )
         result = result.replace(
-            self._template.project_name.package, self.project_name.package
+            self.template.project_name.package, self.project_name.package
         )
-        result = result.replace(self._template.author, self.author)
-        result = result.replace(self._template.email, self.email)
-        result = result.replace(self._template.licence, self.licence)
+        result = result.replace(self.template.author, self.author)
+        result = result.replace(self.template.email, self.email)
+        result = result.replace(self.template.licence, self.licence)
         return result
