@@ -1,9 +1,13 @@
 """Licence interactions."""
 import datetime
+import logging
 import typing
 
 import bs4
 import requests
+import retry
+
+_LOGGER = logging.getLogger(__name__)
 
 
 class InvalidError(RuntimeError):
@@ -19,10 +23,11 @@ def text(name: str) -> str:
     response = _download(name)
     maybe_text = _extract(response.text)
     if maybe_text is None:
-        raise RuntimeError(f"Could not find id=LicenseText in {response.url}.")
+        raise RuntimeError(f"Could not find licence text in {response.url}.")
     return maybe_text
 
 
+@retry.retry(UnavailableError, tries=2, logger=_LOGGER)
 def _download(name: str) -> requests.Response:
     url = f"https://opensource.org/licenses/{name}"
     response = requests.get(url, timeout=datetime.timedelta(minutes=1).total_seconds())
@@ -36,5 +41,7 @@ def _download(name: str) -> requests.Response:
 
 def _extract(html: str) -> typing.Optional[str]:
     soup = bs4.BeautifulSoup(html, features="html.parser")
-    result = soup.find(id="LicenseTest")
-    return result.text if result is not None else None
+    result = soup.find(name="div", id="LicenseText")
+    if not result:
+        result = soup.find(name="article")
+    return result.text.strip() if result is not None else None
